pub struct ClientBlockBuilder<'a> { /* private fields */ }
Builder of the block API

Implementations

Prepare a transaction

Sign the transaction

Create block builder

Allow burning of native tokens when custom inputs are provided.

Sets the seed.

Sets the coin type.

Sets the account index.

Sets the index of the address to start looking for balance.

Set a custom input(transaction output)

Set a custom range in which to search for addresses for custom provided inputs. Default: 0..100

Set a transfer to the builder

Set outputs to the builder

Set a transfer to the builder, address needs to be hex encoded

Set a custom remainder address

Set tagged_data to the builder

Set data to the builder

Set 1-8 custom parent block ids

Set multiple options from client block builder options type Useful for bindings

Consume the builder and get the API result

Get output amount and address from an OutputDto, governance_transition for Alias Outputs so we get the unlock condition we’re interested in

Consume the builder and get the API result

Builds the final block and posts it to the node