Struct iota_client::api::ClientMessageBuilder [−][src]
pub struct ClientMessageBuilder<'a> { /* fields omitted */ }Expand description
Builder of the message API
Implementations
Sets the account index.
Sets the index of the address to start looking for balance.
Set a custom input(transaction output)
Set a custom range in which to search for addresses for custom inputs. Default: 0..100
Set a transfer to the builder
Set a dust allowance transfer to the builder, address needs to be Bech32 encoded
Set a transfer to the builder, address needs to be hex encoded
Set 1-8 custom parent message ids
Consume the builder and get the API result
Consume the builder and get the API result