Struct iota_client::api::RemainderData
source · [−]Expand description
Data for a remainder output, used for ledger nano
Fields
output: OutputThe remainder output
chain: Option<Chain>The chain derived from seed, for the remainder addresses
address: AddressThe remainder address