Struct iota_client::api::RemainderDataDto
source · [−]pub struct RemainderDataDto {
pub output: OutputDto,
pub chain: Option<Chain>,
pub address: AddressDto,
}Expand description
Data for a remainder output, used for ledger nano
Fields
output: OutputDtoThe remainder output
chain: Option<Chain>The chain derived from seed, for the remainder addresses
address: AddressDtoThe remainder address