pub struct NodeInfoWrapper {
    pub nodeinfo: NodeInfo,
    pub url: String,
}
NodeInfo wrapper which contains the nodeinfo and the url from the node (useful when multiple nodes are used)

Fields

nodeinfo: NodeInfo

The returned nodeinfo

url: String

The url from the node which returned the nodeinfo