Struct iota_client::node::GetAddressBuilder
source · [−]pub struct GetAddressBuilder<'a> { /* private fields */ }Expand description
Builder of GET /api/v1/address/{address} endpoint
Implementations
sourceimpl<'a> GetAddressBuilder<'a>
impl<'a> GetAddressBuilder<'a>
sourcepub async fn balance(self, address: &str) -> Result<BalanceAddressResponse>
pub async fn balance(self, address: &str) -> Result<BalanceAddressResponse>
Consume the builder and get the balance of a given Bech32 encoded address. If count equals maxResults, then there might be more outputs available but those were skipped for performance reasons. User should sweep the address to reduce the amount of outputs.
sourcepub async fn outputs(
self,
address: &str,
options: OutputsOptions
) -> Result<Box<[UtxoInput]>>
pub async fn outputs(
self,
address: &str,
options: OutputsOptions
) -> Result<Box<[UtxoInput]>>
Consume the builder and get all outputs that use a given address. If count equals maxResults, then there might be more outputs available but those were skipped for performance reasons. User should sweep the address to reduce the amount of outputs.
sourcepub async fn outputs_response(
self,
address: &str,
options: OutputsOptions
) -> Result<OutputsAddressResponse>
pub async fn outputs_response(
self,
address: &str,
options: OutputsOptions
) -> Result<OutputsAddressResponse>
Consume the builder and get the OutputsAddressResponse for a given address. If count equals maxResults, then there might be more outputs available but those were skipped for performance reasons. User should sweep the address to reduce the amount of outputs.