Struct iota_client::node_api::core::routes::NodeInfoWrapper
source · [−]pub struct NodeInfoWrapper {
pub node_info: InfoResponse,
pub url: String,
}Expand description
NodeInfo wrapper which contains the node info and the url from the node (useful when multiple nodes are used)
Fields
node_info: InfoResponseThe returned node info
url: StringThe url from the node which returned the node info