pub enum QueryParameter {
Show 23 variants Address(String), AliasAddress(String), CreatedAfter(u32), CreatedBefore(u32), Cursor(String), ExpirationReturnAddress(String), ExpiresAfter(u32), ExpiresBefore(u32), Governor(String), HasExpiration(bool), HasNativeTokens(bool), HasStorageDepositReturn(bool), HasTimelock(bool), Issuer(String), MaxNativeTokenCount(u32), MinNativeTokenCount(u32), PageSize(usize), Sender(String), StateController(String), StorageDepositReturnAddress(String), Tag(String), TimelockedAfter(u32), TimelockedBefore(u32),
}
Query parameter for output requests.

Variants

Address(String)

Bech32-encoded address that should be searched for.

AliasAddress(String)

Filter foundry outputs based on bech32-encoded address of the controlling alias.

CreatedAfter(u32)

Returns outputs that were created after a certain Unix timestamp.

CreatedBefore(u32)

Returns outputs that were created before a certain Unix timestamp.

Cursor(String)

Starts the search from the cursor (confirmationMS+outputId.pageSize).

ExpirationReturnAddress(String)

Filters outputs based on the presence of a specific Bech32-encoded return address in the expiration unlock condition.

ExpiresAfter(u32)

Returns outputs that expire after a certain Unix timestamp.

ExpiresBefore(u32)

Returns outputs that expire before a certain Unix timestamp.

Governor(String)

Filters outputs based on bech32-encoded governor (governance controller) address.

HasExpiration(bool)

Filters outputs based on the presence of expiration unlock condition.

HasNativeTokens(bool)

Filters outputs based on the presence of native tokens.

HasStorageDepositReturn(bool)

Filters outputs based on the presence of storage deposit return unlock condition.

HasTimelock(bool)

Filters outputs based on the presence of timelock unlock condition.

Issuer(String)

Filters outputs based on bech32-encoded issuer address.

MaxNativeTokenCount(u32)

Filters outputs that have at most a certain number of distinct native tokens.

MinNativeTokenCount(u32)

Filters outputs that have at least a certain number of distinct native tokens.

PageSize(usize)

The maximum amount of items returned in one call. If there are more items, a cursor to the next page is returned too. The parameter is ignored when pageSize is defined via the cursor parameter.

Sender(String)

Filters outputs based on the presence of validated Sender (bech32 encoded).

StateController(String)

Filters outputs based on bech32-encoded state controller address.

StorageDepositReturnAddress(String)

Filters outputs based on the presence of a specific return address in the storage deposit return unlock condition.

Tag(String)

Filters outputs based on matching Tag Block.

TimelockedAfter(u32)

Returns outputs that are timelocked after a certain Unix timestamp.

TimelockedBefore(u32)

Returns outputs that are timelocked before a certain Unix timestamp.