Module iota_client::node_manager
source · [−]Expand description
The node manager that takes care of sending requests and quroum if enabled
Structs
Node struct
JSON struct for NodeDetail from the node_pool_urls
Functions
Validates if the url starts with http or https