Module iota_client::node_manager::builder
source · [−]Expand description
The node manager that takes care of sending requests with healthy nodes and quorum if enabled
Structs
Node manager builder
Functions
Validates if the url starts with http or https