pub struct NodeManagerBuilder {
    pub primary_node: Option<NodeDto>,
    pub primary_pow_node: Option<NodeDto>,
    pub nodes: HashSet<NodeDto>,
    pub permanodes: Option<HashSet<NodeDto>>,
    pub node_sync_enabled: bool,
    pub node_sync_interval: Duration,
    pub quorum: bool,
    pub min_quorum_size: usize,
    pub quorum_threshold: usize,
}
Node manager builder

Fields

primary_node: Option<NodeDto>

Node which will be tried first for all requests

primary_pow_node: Option<NodeDto>

Node which will be tried first when using remote PoW, even before the primary_node

nodes: HashSet<NodeDto>

Nodes

permanodes: Option<HashSet<NodeDto>>

Permanodes

node_sync_enabled: bool

If node syncing is enabled

node_sync_interval: Duration

Interval in which nodes will be checked for their sync status and the [NetworkInfo] gets updated

quorum: bool

If node quorum is enabled. Will compare the responses from multiple nodes and only returns the response if quorum_threshold% of the nodes return the same one

min_quorum_size: usize

Minimum amount of nodes required for request when quorum is enabled

quorum_threshold: usize

% of nodes that have to return the same response so it gets accepted