Structs for nodes

Structs

Node definition.
Node authentication object.
A parsed URL record.

Enums

NodeDto enum to accept just a single url or also provided auth options or set if the node should be disabled.