Enum iota_client::node_manager::node::NodeDto
source · [−]Expand description
NodeDto enum to accept just a single url or also provided auth options or set if the node should be disabled.
Variants
Url(Url)
Node url
Node(Node)
Node