Struct iota_client::builder::ClientBuilder [−][src]
pub struct ClientBuilder { /* fields omitted */ }Expand description
Builder to construct client instance with sensible default values
Implementations
Adds an IOTA node by its URL to be used as primary node, with optional jwt and or basic authentication
Adds an IOTA node by its URL to be used as primary PoW node (for remote PoW), with optional jwt and or basic authentication
Adds a permanode by its URL, with optional jwt and or basic authentication
Adds an IOTA node by its URL with optional jwt and or basic authentication
Set the node sync interval
Disables the node syncing process. Every node will be considered healthy and ready to use.
Get node list from the node_pool_urls
Set if quroum should be used or not
Set amount of nodes which should be used for quorum
Set quorum_threshold
Selects the type of network to get default nodes for it, only “testnet” is supported at the moment. Nodes that don’t belong to this network are ignored. Default nodes are only used when no other nodes are provided.
Sets whether the PoW should be done locally or remotely.
Sets after how many seconds new tips will be requested during PoW
Sets the default request timeout.
Sets the request timeout for a specific API usage.