Struct iota_client::client::NodeInfoWrapper
source · [−]Expand description
NodeInfo wrapper which contains the nodeinfo and the url from the node (useful when multiple nodes are used)
Fields
nodeinfo: NodeInfoThe returned nodeinfo
url: StringThe url from the node which returned the nodeinfo