Enum iota_client::error::Error
source · [−]pub enum Error {
Show 43 variants
ApiTypes(Error),
Blake2b256Error(&'static str),
BlockDtoError(DtoError),
BlockError(Error),
ConsolidationRequired(usize),
CryptoError(Error),
InputAddressNotFound(String, String),
InvalidAmount(String),
InvalidBIP32ChainData,
InvalidMnemonic(String),
Json(Error),
MissingInput(String),
MissingParameter(&'static str),
MissingInputWithEd25519Address,
NodeError(String),
NoNeedPromoteOrReattach(String),
NotFound(String),
NotEnoughBalance {
found: u64,
required: u64,
},
NoInputs,
NotEnoughNativeTokens(NativeTokens),
NoBalanceForNativeTokenRemainder,
OutputError(&'static str),
PlaceholderSecretManager,
PoisonError,
Pow(String),
PrefixHexError(Error),
QuorumPoolSizeError {
available_nodes: usize,
minimum_threshold: usize,
},
QuorumThresholdError {
quorum_size: usize,
minimum_threshold: usize,
},
ResponseError {
code: u16,
text: String,
url: String,
},
ReqwestError(Error),
SecretManagerMismatch,
HealthyNodePoolEmpty,
TaggedDataError(String),
TangleInclusionError(String),
TaskJoinError(JoinError),
TimeNotSynced {
current_time: u32,
milestone_timestamp: u32,
},
TransactionSemantic(ConflictReason),
UnexpectedApiResponse,
UnsupportedQueryParameter(QueryParameter),
UnpackError(UnpackError<Error, UnexpectedEOF>),
UrlAuthError(&'static str),
UrlError(ParseError),
UrlValidationError(String),
}Expand description
Error type of the iota client crate.
Variants
ApiTypes(Error)
Block dtos error
Blake2b256Error(&'static str)
Blake2b256 Error
BlockDtoError(DtoError)
Block dtos error
BlockError(Error)
Block types error
ConsolidationRequired(usize)
The wallet account has enough funds, but split on too many outputs
CryptoError(Error)
Crypto.rs error
InputAddressNotFound(String, String)
Address not found
InvalidAmount(String)
Invalid amount in API response
InvalidBIP32ChainData
Invalid BIP32 chain data
InvalidMnemonic(String)
Invalid mnemonic error
Json(Error)
JSON error
MissingInput(String)
Missing input for utxo chain
MissingParameter(&'static str)
Missing required parameters
MissingInputWithEd25519Address
No input with matching ed25519 address provided
NodeError(String)
Error on API request
NoNeedPromoteOrReattach(String)
The block doesn’t need to be promoted or reattached
NotFound(String)
The requested data was not found.
NotEnoughBalance
The wallet account doesn’t have enough balance
NoInputs
The wallet account doesn’t have any inputs found
NotEnoughNativeTokens(NativeTokens)
The wallet account doesn’t have enough native tokens
NoBalanceForNativeTokenRemainder
The wallet account doesn’t have enough balance for an output with the remaining native tokens.
OutputError(&'static str)
Output Error
PlaceholderSecretManager
PlaceholderSecretManager can’t be used for address generation or signing
PoisonError
Rw lock failed.
Pow(String)
PoW error
PrefixHexError(Error)
Prefix hex string convert error
QuorumPoolSizeError
Fields
available_nodes: usizeThe number of nodes available for quorum.
minimum_threshold: usizeThe minimum quorum threshold.
Error on quorum because not enough nodes are available
QuorumThresholdError
Fields
quorum_size: usizeThe current quorum size.
minimum_threshold: usizeThe minimum quorum threshold.
Error on reaching quorum
ResponseError
Fields
code: u16The status code.
text: StringThe text from the response.
url: StringThe url of the API.
Error from RestAPI calls with unexpected status code response
ReqwestError(Error)
reqwest error
SecretManagerMismatch
Specifically used for TryInfo implementations for SecretManager.
HealthyNodePoolEmpty
No node available in the healthy node pool
TaggedDataError(String)
Error when building tagged_data blocks
TangleInclusionError(String)
The block cannot be included into the Tangle
TaskJoinError(JoinError)
Tokio task join error
TimeNotSynced
Fields
current_time: u32The local time.
milestone_timestamp: u32The timestamp of the latest milestone.
Local time doesn’t match the time of the latest milestone timestamp
TransactionSemantic(ConflictReason)
The semantic validation of a transaction failed.
UnexpectedApiResponse
Unexpected API response error
UnsupportedQueryParameter(QueryParameter)
An indexer API request contains a query parameter not supported by the endpoint.
UnpackError(UnpackError<Error, UnexpectedEOF>)
Unpack error
UrlAuthError(&'static str)
URL auth error
UrlError(ParseError)
URL error
UrlValidationError(String)
URL validation error