pub enum Error {
Show 39 variants IndexationError(String), TransactionError, NotEnoughBalance(u64u64), ConsolidationRequired(usize), DustError(String), MissingParameter(&'static str), InvalidParameter(&'static str), SyncedNodePoolEmpty, NodePoolUrlsError, QuorumThresholdError(usizeusize), QuorumPoolSizeError(usizeusize), NodeError(String), NodeReadError, FromHexError(FromHexError), MessageError(Error), BeeRestApiError(Error), NoNeedPromoteOrReattach(String), TangleInclusionError(String), InvalidMqttTopic(String), MqttConnectionNotFound, IoError(Error), Json(Error), Pow(String), InputAddressNotFound(StringString), CryptoError(Error), MnemonicError(String), InvalidParentsAmount(usize), ResponseError(u16String), ReqwestError(Error), UrlError(ParseError), UrlValidationError(String), UrlAuthError(String), Blake2b256Error(&'static str), OutputError(&'static str), TaskJoinError(JoinError), InvalidMnemonic(String), PowError(Error), ApiError, PoisonError,
}
Error type of the iota client crate.

Variants

IndexationError(String)

Error when building indexation messages

TransactionError

Error when building transaction messages

NotEnoughBalance(u64u64)

The wallet account doesn’t have enough balance

ConsolidationRequired(usize)

The wallet account doesn’t have enough balance

DustError(String)

Dust error, for example not enough balance on an address

MissingParameter(&'static str)

Missing required parameters

InvalidParameter(&'static str)

Invalid parameters

SyncedNodePoolEmpty

No node available in the synced node pool

NodePoolUrlsError

Error on Url type conversion

QuorumThresholdError(usizeusize)

Error on reaching quorum

QuorumPoolSizeError(usizeusize)

Error on quorum because not enough nodes are available

NodeError(String)

Error on API request

NodeReadError

Error on RwLock read

FromHexError(FromHexError)

Hex string convert error

MessageError(Error)

Message types error

BeeRestApiError(Error)

Bee rest api error

NoNeedPromoteOrReattach(String)

The message doensn’t need to be promoted or reattached

TangleInclusionError(String)

The message cannot be included into the Tangle

InvalidMqttTopic(String)

Invalid MQTT topic.

MqttConnectionNotFound

MQTT connection not found (all nodes MQTT’s are disabled)

IoError(Error)

IO error

Json(Error)

JSON error

Pow(String)

PoW error

InputAddressNotFound(StringString)

Address not found

CryptoError(Error)

Crypto.rs error

MnemonicError(String)

Crypto.rs mnemonic error

InvalidParentsAmount(usize)

Invalid amount of parents

ResponseError(u16String)

Error from RestAPI calls with unexpected status code response

ReqwestError(Error)

reqwest error

UrlError(ParseError)

URL error

UrlValidationError(String)

URL validation error

UrlAuthError(String)

URL auth error

Blake2b256Error(&'static str)

Blake2b256 Error

OutputError(&'static str)

Output Error

TaskJoinError(JoinError)

Tokio task join error

InvalidMnemonic(String)

Invalid mnemonic error

PowError(Error)

PoW error

ApiError

API error

PoisonError

Rw lock failed.