Module iota_client::node_manager[][src]

The node manager that takes care of sending requests and quroum if enabled

Structs

Node

Node struct

NodeDetail

JSON struct for NodeDetail from the node_pool_urls

Functions

validate_url

Validates if the url starts with http or https